pub fn generate_id_token(
user_id: Uuid,
client_id: &str,
nonce: Option<&str>,
expires_at: DateTime<Utc>,
issuer: &str,
cfg: &ApplicationConfiguration,
) -> Result<String, ControllerError>Expand description
Generate an ID token. nonce should be Some only when the authorization request
included a nonce; when absent or empty, the nonce claim is omitted from the id_token.